diff sat_frontends/jp/constants.py @ 2777:ff1b40823b07

jp (pubsub): new "transform" command: This command allows to pass all requested items through an external command to filter them (i.e. modify their content). - created new jp.xml_tools module with some common functions (like lxml parsing) - new EXIT code EXIT_CMD_ERROR (used when a third party utility returns an error)
author Goffi <goffi@goffi.org>
date Tue, 15 Jan 2019 08:51:56 +0100
parents 003b8b4b56a7
children ab2696e34d29
line wrap: on
line diff
--- a/sat_frontends/jp/constants.py	Tue Jan 15 08:51:54 2019 +0100
+++ b/sat_frontends/jp/constants.py	Tue Jan 15 08:51:56 2019 +0100
@@ -80,10 +80,12 @@
     EXIT_BRIDGE_ERROR = 3  # can't connect to bridge
     EXIT_BRIDGE_ERRBACK = 4  # something went wrong when calling a bridge method
     EXIT_NOT_FOUND = 16  # an item required by a command was not found
-    EXIT_DATA_ERROR = 17  #  data needed for a command is invalid
+    EXIT_DATA_ERROR = 17  # data needed for a command is invalid
+    EXIT_MISSING_FEATURE = 18  # a needed plugin or feature is not available
     EXIT_USER_CANCELLED = 20  # user cancelled action
     EXIT_FILE_NOT_EXE = (
         126
     )  # a file to be executed was found, but it was not an executable utility (cf. man 1 exit)
     EXIT_CMD_NOT_FOUND = 127  # a utility to be executed was not found (cf. man 1 exit)
+    EXIT_CMD_ERROR = 127  # a utility to be executed returned an error exit code
     EXIT_SIGNAL_INT = 128  # a command was interrupted by a signal (cf. man 1 exit)